import Visibility from '@mui/icons-material/Visibility';
import VisibilityOff from '@mui/icons-material/VisibilityOff';
import { Box, Button } from '@mui/material';
import FormControl from '@mui/material/FormControl';
import FormControlLabel from '@mui/material/FormControlLabel';
import FormLabel from '@mui/material/FormLabel';
import IconButton from '@mui/material/IconButton';
import InputAdornment from '@mui/material/InputAdornment';
import OutlinedInput from '@mui/material/OutlinedInput';
import Radio from '@mui/material/Radio';
import RadioGroup from '@mui/material/RadioGroup';
import Form from 'components/common/Form/Form';
import InputForm from 'components/common/Input/InputForm';
import inputFormClasses from 'components/common/Input/InputForm.module.css';
import useAuth from 'hooks/useAuth';
import { useSnackbar } from 'notistack';
import { useState } from 'react';
import axios from 'services/axios';
import * as backendUrl from 'services/backendUrl';
import { displaySnackbar } from 'utils/snackbar';

export default function SignUpSection({ handleCloseModal }) {
    const [email, setEmail] = useState('');
    const [firstName, setFirstName] = useState('');
    const [lastName, setLastName] = useState('');
    const [dateOfBirth, setDateOfBirth] = useState(null);
    const [gender, setGender] = useState('MALE');
    const [password, setPassword] = useState('');
    const [confirmedPassword, setConfirmedPassword] = useState('');
    const [showPassword, setShowPassword] = useState(false);
    const [showConfirmedPassword, setShowConfirmedPassword] = useState(false);
    const { setAuth, setPersist } = useAuth();
    const { enqueueSnackbar, closeSnackbar } = useSnackbar();

    const handleChange = (event) => {
        setGender(event.target.value);
    };

    const handleClickShowPassword = () => setShowPassword((show) => !show);
    const handleClickShowConfirmedPassword = () => setShowConfirmedPassword((show) => !show);

    const handleMouseDownPassword = (event) => {
        event.preventDefault();
    };

    const validateThatPasswordMatches = () => {
        return password === confirmedPassword;
    };

    const handleSubmitButton = (event) => {
        event.preventDefault();
        if (!validateThatPasswordMatches()) {
            enqueueSnackbar('Пароли не совпадают', {
                variant: 'error'
            });
        } else {
            axios
                .post(`${backendUrl.signUpUrl}`, {
                    email: email,
                    first_name: firstName,
                    last_name: lastName,
                    sex: gender,
                    birthday: dateOfBirth,
                    password: password
                })
                .then((response) => {
                    if (response.status === 200) {
                        const accessToken = response?.data?.access_token;
                        const updateToken = response?.data?.update_token;
                        const role = response?.data?.role;
                        setAuth({ accessToken, updateToken, role });
                        setPersist(true);
                        localStorage.setItem('updateToken', updateToken);
                        handleCloseModal();
                        const message = 'Вы успешно зарегистрировались в системе';
                        const snackbarKey = displaySnackbar(message, 'success');
                    }
                })
                .catch((error) => {
                    if (error.response) {
                        enqueueSnackbar(error.response.data, {
                            variant: 'error'
                        });
                    } else if (error.request) {
                        enqueueSnackbar('Произошла ошибка при отправке запроса', {
                            variant: 'error'
                        });
                    } else {
                        console.log('Error', error.message);
                    }
                });
        }
    };

    return (
        <>
            <p className="text-3xl font-normal">Регистрация</p>
            <Form
                onSubmit={handleSubmitButton}
                className="flex flex-column flex-wrap justify-start items-center gap-3 px-3">
                <InputForm
                    className="text-lg lg:text-2xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full"
                    type="email"
                    placeholder="Введите email"
                    required
                    onChange={(e) => setEmail(e.target.value)}
                />
                <InputForm
                    className="text-lg lg:text-2xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full"
                    type="text"
                    placeholder="Введите имя"
                    required
                    onChange={(e) => setFirstName(e.target.value)}
                />
                <InputForm
                    className="text-lg lg:text-2xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full"
                    type="text"
                    placeholder="Введите фамилию"
                    required
                    onChange={(e) => setLastName(e.target.value)}
                />
                <InputForm
                    className="text-lg lg:text-2xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full"
                    type="date"
                    placeholder="Выберите дату рождения"
                    onChange={(e) => setDateOfBirth(e.target.value)}
                />
                <div className={inputFormClasses.genderSelection}>
                    <FormControl>
                        <FormLabel
                            className={[
                                inputFormClasses.genderSelectionText,
                                'text-lg xl:text-2xl'
                            ].join(' ')}
                            id="controlled-radio-buttons-group">
                            Пол
                        </FormLabel>
                        <RadioGroup
                            aria-labelledby="controlled-radio-buttons-group"
                            name="controlled-radio-buttons-group"
                            value={gender}
                            onChange={handleChange}>
                            <FormControlLabel
                                className={[
                                    inputFormClasses.genderSelectionText,
                                    'text-lg xl:text-2xl'
                                ].join(' ')}
                                value="MALE"
                                control={<Radio />}
                                label="Мужской"
                            />
                            <FormControlLabel
                                className={[
                                    inputFormClasses.genderSelectionText,
                                    'text-lg xl:text-2xl'
                                ].join(' ')}
                                value="FEMALE"
                                control={<Radio />}
                                label="Женский"
                            />
                        </RadioGroup>
                    </FormControl>
                </div>
                <OutlinedInput
                    className="text-lg lg:text-2xl p-0 bg-[#fefefe] rounded-md w-full"
                    type={showPassword ? 'text' : 'password'}
                    placeholder="Введите пароль"
                    onChange={(e) => setPassword(e.target.value)}
                    required
                    endAdornment={
                        <InputAdornment position="end">
                            <IconButton
                                className={inputFormClasses.eyeIcon}
                                aria-label="toggle password visibility"
                                onClick={handleClickShowPassword}
                                onMouseDown={handleMouseDownPassword}
                                edge="end">
                                {showPassword ? <VisibilityOff /> : <Visibility />}
                            </IconButton>
                        </InputAdornment>
                    }
                />
                <OutlinedInput
                    className="text-lg lg:text-2xl p-0 bg-[#fefefe] rounded-md w-full"
                    type={showConfirmedPassword ? 'text' : 'password'}
                    placeholder="Повторите пароль"
                    onChange={(e) => setConfirmedPassword(e.target.value)}
                    required
                    endAdornment={
                        <InputAdornment position="end">
                            <IconButton
                                className={inputFormClasses.eyeIcon}
                                aria-label="toggle password visibility"
                                onClick={handleClickShowConfirmedPassword}
                                onMouseDown={handleMouseDownPassword}
                                edge="end">
                                {showConfirmedPassword ? <VisibilityOff /> : <Visibility />}
                            </IconButton>
                        </InputAdornment>
                    }
                />
                <Box mb={3} className="w-full">
                    <Button
                        className="bg-[var(--color-purple)] rounded-lg font-normal text-[var(--color-form-white)] py-2 w-full text-2xl"
                        type="submit">
                        Зарегистрироваться
                    </Button>
                </Box>
            </Form>
        </>
    );
}
